==> mingw-w64-freecad-0.21.2-7.src.tar.zst: FreeCAD-0.21.2/src/App/Resources/translations/App_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu" sourcelanguage="en">
  <context>
    <name>LinkParams</name>
    <message>
      <location filename="../../Link.cpp" line="119"/>
      <source>Stores the last user choice of whether to apply CopyOnChange setup to all links
that reference the same configurable object</source>
      <translation>Tárolja a felhasználó legutóbbi döntését, hogy a CopyOnChange beállítás minden hivatkozásra alkalmazható-e,
amelyek ugyanarra a konfigurálható tárgyra hivatkoznak</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Application.cpp" line="441"/>
      <source>Unnamed</source>
      <translation>Névtelen</translation>
    </message>
  </context>
  <context>
    <name>App::Origin</name>
    <message>
      <location filename="../../Origin.cpp" line="140"/>
      <source>X-axis</source>
      <translation>X-tengely</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="141"/>
      <source>Y-axis</source>
      <translation>Y tengely</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="142"/>
      <source>Z-axis</source>
      <translation>Z tengely</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="143"/>
      <source>XY-plane</source>
      <translation>XY sík</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="144"/>
      <source>XZ-plane</source>
      <translation>XZ sík</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="145"/>
      <source>YZ-plane</source>
      <translation>YZ síkban</translation>
    </message>
  </context>
  <context>
    <name>App::OriginGroupExtension</name>
    <message>
      <location filename="../../OriginGroupExtension.cpp" line="134"/>
      <source>Origin</source>
      <translation>Kezdőpont</translation>
    </message>
  </context>
</TS>

==> mingw-w64-freecad-1.0rc1-1.src.tar.zst: FreeCAD-1.0rc1/src/App/Resources/translations/App_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu" sourcelanguage="en">
  <context>
    <name>LinkParams</name>
    <message>
      <location filename="../../Link.cpp" line="118"/>
      <source>Stores the last user choice of whether to apply CopyOnChange setup to all links
that reference the same configurable object</source>
      <translation>Tárolja a felhasználó legutóbbi döntését, hogy a CopyOnChange beállítás minden összekötésre alkalmazható-e,
amelyek ugyanarra a konfigurálható tárgyra hivatkoznak</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Application.cpp" line="459"/>
      <source>Unnamed</source>
      <translation>Névtelen</translation>
    </message>
  </context>
  <context>
    <name>App::Origin</name>
    <message>
      <location filename="../../Origin.cpp" line="142"/>
      <source>X-axis</source>
      <translation>X-tengely</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="143"/>
      <source>Y-axis</source>
      <translation>Y tengely</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="144"/>
      <source>Z-axis</source>
      <translation>Z tengely</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="145"/>
      <source>XY-plane</source>
      <translation>XY sík</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="146"/>
      <source>XZ-plane</source>
      <translation>XZ sík</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="147"/>
      <source>YZ-plane</source>
      <translation>YZ síkban</translation>
    </message>
  </context>
  <context>
    <name>App::OriginGroupExtension</name>
    <message>
      <location filename="../../OriginGroupExtension.cpp" line="134"/>
      <source>Origin</source>
      <translation>Kezdőpont</translation>
    </message>
  </context>
</TS>
